package com.app.ui.activity

import android.graphics.Rect
import android.os.Bundle
import android.support.v7.widget.GridLayoutManager
import android.support.v7.widget.RecyclerView
import android.text.Html
import android.view.View
import com.app.R
import com.app.YYApplication
import com.app.api.InterfaceUrlConstants
import com.app.api.RequestApiData
import com.app.constants.KeyConstants
import com.app.constants.RazorConstants
import com.app.event.BatchSayHelloEvent
import com.app.event.CustomSayHelloEvent
import com.app.model.request.BatchSayHelloRequest
import com.app.model.response.BatchSayHelloResponse
import com.app.model.response.TakeWelfareGirlUserResponse
import com.app.ui.YYBaseActivity
import com.app.ui.adapter.VipWelfareAdapter
import com.app.util.EventBusHelper
import com.app.util.Tools
import com.app.widget.dialog.ChangeInfomationDialog
import com.app.widget.dialog.CustomDialog
import com.wbtech.ums.UmsAgent
import com.yy.ui.fragment.ActionBarFragment
import com.yy.util.net.NewHttpResponeCallBack
import com.yy.util.string.StringUtils
import kotlinx.android.synthetic.main.vip_welfare_activity_layout.*

/**
 * Created by liujiawei on 27/12/2017.
 */
class VipWelfareActivity : YYBaseActivity(), NewHttpResponeCallBack {

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.vip_welfare_activity_layout)
        EventBusHelper.getDefault().register(this)
        initTitle()
        initView()
        initData()
    }

    private fun initData() {
        showLoadingDialog("正在加载...")
        RequestApiData.getInstance().takeWelfareGirlUser(TakeWelfareGirlUserResponse::class.java, this@VipWelfareActivity)
    }

    private var vipWelfareAdapter: VipWelfareAdapter? = null
    private var isShowWork: Int = 0

    private fun initView() {
        UmsAgent.onEvent(this, RazorConstants.VIP_WELFARE)

        val currentUser = YYApplication.getInstance().currentUser
        if (currentUser != null) {
            id_describe.text = Html.fromHtml(String.format(getString(R.string.vip_welfare_describe), currentUser.nickName))
        }
        id_say_hello.setOnClickListener {
            requestBatchSayHello()
        }

        val gridLayoutManager = GridLayoutManager(this, 3, GridLayoutManager.VERTICAL, false)
        id_list.layoutManager = gridLayoutManager
        id_list.isEnabled = false
        vipWelfareAdapter = VipWelfareAdapter()
        id_list.adapter = vipWelfareAdapter

        id_list.addItemDecoration(object : RecyclerView.ItemDecoration() {
            override fun getItemOffsets(outRect: Rect?, view: View?, parent: RecyclerView?, state: RecyclerView.State?) {
                super.getItemOffsets(outRect, view, parent, state)
                if (parent!!.getChildPosition(view) > 2) {
                    outRect?.top = Tools.dp2px(25f)
                }
            }
        })
    }

    private fun initTitle() {
        val actionBarFragment = supportFragmentManager.findFragmentById(R.id.action_bar_fragment) as ActionBarFragment
        actionBarFragment.rightBtnVisible = View.VISIBLE
        actionBarFragment.setTitleName("会员福利")
        actionBarFragment.setLeftBtnImage(R.drawable.btn_back_selector
        ) { finish() }
    }

    /**
     * 打招呼(群)
     */
    private fun requestBatchSayHello() {


        val currentUser = YYApplication.getInstance().currentUser
        if (currentUser != null) {
            if (isShowWork == 1) {
                //显示斗米
                var changeInfomation = ChangeInfomationDialog
                        .newInstance(KeyConstants.KEY_DOUMI_WORK, null, "")
                changeInfomation.setOnCompleteListener { flag, `object` ->
                    isShowWork = 0
                }
                changeInfomation.show(supportFragmentManager, "dialog")

                UmsAgent.onEvent(this, RazorConstants.DOUMI_WELFARE_DIALOG_SHOW)
                return
            }
        }


        //自定义招呼
        val configInfo = YYApplication.getInstance().configInfo
        if (configInfo != null) {
            val sayHelloCfg = configInfo.sayHelloCfg
            if (sayHelloCfg != null) {
                if (StringUtils.isEmpty(sayHelloCfg.content)) {
                    CustomDialog.getInstance(CustomDialog.DialogType.VIP_WELFARE_CUSTOM_SAY_HELLO).show(supportFragmentManager)
                    return
                }
            } else {
                CustomDialog.getInstance(CustomDialog.DialogType.VIP_WELFARE_CUSTOM_SAY_HELLO).show(supportFragmentManager)
                return
            }
        }


        if (ids.isEmpty()) {
            return
        }
        UmsAgent.onEvent(this, RazorConstants.VIP_WELFARE_SAY_HELLO)
        val request = BatchSayHelloRequest(6, ids)
        RequestApiData.getInstance().batchSayHello(request, BatchSayHelloResponse::class.java, this@VipWelfareActivity)
    }

    override fun onResponeStart(apiName: String?) {

    }

    override fun onLoading(apiName: String?, count: Long, current: Long) {
    }

    override fun onSuccess(apiName: String?, `object`: Any?) {
        if (InterfaceUrlConstants.URL_TAKEWELFAREGIRLUSER == apiName) {
            if (`object` is TakeWelfareGirlUserResponse) {
                val response = `object`
                if (`object`.listUser.isNotEmpty()) {
                    vipWelfareAdapter?.setData(`object`.listUser)
                    vipWelfareAdapter?.notifyDataSetChanged()
                    `object`.listUser.map {
                        ids.add(it.id)
                    }
                    isShowWork = response.isShowWorkWelfare
                }
            }
        } else if (InterfaceUrlConstants.URL_BATCHSAYHELLO == apiName) {
            if (`object` is BatchSayHelloResponse) {

                Tools.showToast(`object`.msg)
                if (`object`.isSucceed == 1) {
                    val configInfo = YYApplication.getInstance().configInfo
                    if (configInfo != null) {
                        if (configInfo.otherCfg != null) {
                            configInfo.otherCfg.isShowVipWelfare = 0
                        }
                    }
                    EventBusHelper.getDefault().post(BatchSayHelloEvent(0))
                    finish()
                }
            }
        }
        dismissLoadingDialog()
    }

    fun onEventMainThread(event: CustomSayHelloEvent) {
        id_say_hello.performClick()
    }

    override fun onFailure(apiName: String?, t: Throwable?, errorNo: Int, strMsg: String?) {
        dismissLoadingDialog()
        Tools.showToast(strMsg)
    }

    override fun onDestroy() {
        super.onDestroy()
        EventBusHelper.getDefault().unregister(this)
        ids.clear()
    }


    private var ids: ArrayList<String> = ArrayList()

}